==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/securityhub/kotlin/inputs/InsightFiltersLastObservedAtArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.securityhub.kotlin.inputs

import com.pulumi.aws.securityhub.inputs.InsightFiltersLastObservedAtArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 *
 * @property dateRange A configuration block of the date range for the date filter. See date_range below for more details.
 * @property end An end date for the date filter. Required with `start` if `date_range` is not specified.
 * @property start A start date for the date filter. Required with `end` if `date_range` is not specified.
 */
public data class InsightFiltersLastObservedAtArgs(
    public val dateRange: Output<InsightFiltersLastObservedAtDateRangeArgs>? = null,
    public val end: Output<String>? = null,
    public val start: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.aws.securityhub.inputs.InsightFiltersLastObservedAtArgs> {
    override fun toJava(): com.pulumi.aws.securityhub.inputs.InsightFiltersLastObservedAtArgs =
        com.pulumi.aws.securityhub.inputs.InsightFiltersLastObservedAtArgs.builder()
            .dateRange(dateRange?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .end(end?.applyValue({ args0 -> args0 }))
            .start(start?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [InsightFiltersLastObservedAtArgs].
 */
@PulumiTagMarker
public class InsightFiltersLastObservedAtArgsBuilder internal constructor() {
    private var dateRange: Output<InsightFiltersLastObservedAtDateRangeArgs>? = null

    private var end: Output<String>? = null

    private var start: Output<String>? = null

    /**
     * @param value A configuration block of the date range for the date filter. See date_range below for more details.
     */
    @JvmName("bajxiflheukrusfs")
    public suspend fun dateRange(`value`: Output<InsightFiltersLastObservedAtDateRangeArgs>) {
        this.dateRange = value
    }

    /**
     * @param value An end date for the date filter. Required with `start` if `date_range` is not specified.
     */
    @JvmName("rvfnaybiuchxdhsx")
    public suspend fun end(`value`: Output<String>) {
        this.end = value
    }

    /**
     * @param value A start date for the date filter. Required with `end` if `date_range` is not specified.
     */
    @JvmName("qrxfdjpwyvthfwgk")
    public suspend fun start(`value`: Output<String>) {
        this.start = value
    }

    /**
     * @param value A configuration block of the date range for the date filter. See date_range below for more details.
     */
    @JvmName("pekeewgurfkspryy")
    public suspend fun dateRange(`value`: InsightFiltersLastObservedAtDateRangeArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dateRange = mapped
    }

    /**
     * @param argument A configuration block of the date range for the date filter. See date_range below for more details.
     */
    @JvmName("hkidulcoxtcqmxxw")
    public suspend
    fun dateRange(argument: suspend InsightFiltersLastObservedAtDateRangeArgsBuilder.() -> Unit) {
        val toBeMapped = InsightFiltersLastObservedAtDateRangeArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.dateRange = mapped
    }

    /**
     * @param value An end date for the date filter. Required with `start` if `date_range` is not specified.
     */
    @JvmName("budovvspywhmymkt")
    public suspend fun end(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.end = mapped
    }

    /**
     * @param value A start date for the date filter. Required with `end` if `date_range` is not specified.
     */
    @JvmName("amxvuccdvevukkmg")
    public suspend fun start(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.start = mapped
    }

    internal fun build(): InsightFiltersLastObservedAtArgs = InsightFiltersLastObservedAtArgs(
        dateRange = dateRange,
        end = end,
        start = start,
    )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/securityhub/kotlin/inputs/InsightFiltersLastObservedAtArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.securityhub.kotlin.inputs

import com.pulumi.aws.securityhub.inputs.InsightFiltersLastObservedAtArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 *
 * @property dateRange A configuration block of the date range for the date filter. See date_range below for more details.
 * @property end An end date for the date filter. Required with `start` if `date_range` is not specified.
 * @property start A start date for the date filter. Required with `end` if `date_range` is not specified.
 */
public data class InsightFiltersLastObservedAtArgs(
    public val dateRange: Output<InsightFiltersLastObservedAtDateRangeArgs>? = null,
    public val end: Output<String>? = null,
    public val start: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.aws.securityhub.inputs.InsightFiltersLastObservedAtArgs> {
    override fun toJava(): com.pulumi.aws.securityhub.inputs.InsightFiltersLastObservedAtArgs =
        com.pulumi.aws.securityhub.inputs.InsightFiltersLastObservedAtArgs.builder()
            .dateRange(dateRange?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .end(end?.applyValue({ args0 -> args0 }))
            .start(start?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [InsightFiltersLastObservedAtArgs].
 */
@PulumiTagMarker
public class InsightFiltersLastObservedAtArgsBuilder internal constructor() {
    private var dateRange: Output<InsightFiltersLastObservedAtDateRangeArgs>? = null

    private var end: Output<String>? = null

    private var start: Output<String>? = null

    /**
     * @param value A configuration block of the date range for the date filter. See date_range below for more details.
     */
    @JvmName("aeqonqdnldhtgprf")
    public suspend fun dateRange(`value`: Output<InsightFiltersLastObservedAtDateRangeArgs>) {
        this.dateRange = value
    }

    /**
     * @param value An end date for the date filter. Required with `start` if `date_range` is not specified.
     */
    @JvmName("eqlkochlgfyromjw")
    public suspend fun end(`value`: Output<String>) {
        this.end = value
    }

    /**
     * @param value A start date for the date filter. Required with `end` if `date_range` is not specified.
     */
    @JvmName("fvypmhflhtpdtxfq")
    public suspend fun start(`value`: Output<String>) {
        this.start = value
    }

    /**
     * @param value A configuration block of the date range for the date filter. See date_range below for more details.
     */
    @JvmName("saknkgvuismchfle")
    public suspend fun dateRange(`value`: InsightFiltersLastObservedAtDateRangeArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dateRange = mapped
    }

    /**
     * @param argument A configuration block of the date range for the date filter. See date_range below for more details.
     */
    @JvmName("obncyekgianvioxq")
    public suspend fun dateRange(argument: suspend InsightFiltersLastObservedAtDateRangeArgsBuilder.() -> Unit) {
        val toBeMapped = InsightFiltersLastObservedAtDateRangeArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.dateRange = mapped
    }

    /**
     * @param value An end date for the date filter. Required with `start` if `date_range` is not specified.
     */
    @JvmName("lvghqngvgfyfwmrj")
    public suspend fun end(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.end = mapped
    }

    /**
     * @param value A start date for the date filter. Required with `end` if `date_range` is not specified.
     */
    @JvmName("hjsgpurcyiymjlss")
    public suspend fun start(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.start = mapped
    }

    internal fun build(): InsightFiltersLastObservedAtArgs = InsightFiltersLastObservedAtArgs(
        dateRange = dateRange,
        end = end,
        start = start,
    )
}
